@@ -4,7 +4,6 @@ import errno
 import logging
 import os
 import re
-import sys
 import warnings
 from base64 import b64encode
 from contextlib import closing
@@ -67,14 +66,14 @@ def make_fd(location, url=None, overwrite=False):
     try:
 
         # sys.audit("%s.resource" % __title__, location)
-        sys.audit("os.open", location)
+        # sys.audit("os.open", location)
         if overwrite:
             fd = os.open(location, fd_flags | os.O_TRUNC, fd_mode)
         else:
             # raises FileExistsError if file exists
             fd = os.open(location, fd_flags | os.O_EXCL, fd_mode)
 
-    except (OSError, PermissionError) as e:
+    except (OSError, IOError) as e:
         if e.errno == errno.EEXIST:
             logger.debug(
                 "[FILE] <%s> already exists at: <%s>" % (url, location))
@@ -231,7 +230,7 @@ class GenericResource(object):
         'text/html',
         'text/xhtml'
     ])
-    html_content_types.__doc__ = "Set of valid html mimetypes."
+    # html_content_types.__doc__ = "Set of valid html mimetypes."
 
     def viewing_html(self):
         """Checks whether the current resource is a html type or not."""
@@ -240,7 +239,7 @@ class GenericResource(object):
     css_content_types = tuple([
         'text/css',
     ])
-    css_content_types.__doc__ = "Set of valid css mimetypes."
+    # css_content_types.__doc__ = "Set of valid css mimetypes."
 
     def viewing_css(self):
         """Checks whether the current resource is a css type or not."""
@@ -250,7 +249,7 @@ class GenericResource(object):
         'text/javascript',
         'application/javascript'
     ])
-    js_content_types.__doc__ = "Set of valid javascript mimetypes."
+    # js_content_types.__doc__ = "Set of valid javascript mimetypes."
 
     def viewing_js(self):
         """Checks whether the current resource is a javascript type or not."""
